@@ -218,6 +218,59 @@ class Batch(Workflow, ModelSQL, ModelView):
                 'state': 'closed',
                 })
 
+    @classmethod
+    def view_header_get(cls):
+        '''
+        view_header_get was removed in 4.2
+
+        We keep this stub that can be called for custom view headers
+        '''
+        pool = Pool()
+        Batch = pool.get('account.batch')
+        BatchJournal = pool.get('account.batch.journal')
+        Company = pool.get('company.company')
+        Fiscalyear = pool.get('account.fiscalyear')
+        Period = pool.get('account.period')
+        Translation = pool.get('ir.translation')
+
+        context = Transaction().context
+        lang_code = 'en_US'
+        if context.get('company'):
+            company = Company(context['company'])
+            if company.party.lang:
+                lang_code = company.party.lang.code
+
+        def get_translated_item(source, model, lang_code):
+            return (Translation.get_source(model, 'field', lang_code, source)
+                or source)
+
+        batch_string = journal_string = period_string = year_string = ''
+        if context.get('journal'):
+            trans_journal = get_translated_item('Journal',
+                'account.batch.line,journal', lang_code)
+            batch_journal = BatchJournal(context['journal'])
+            journal_string = '%s: %s' % (trans_journal, batch_journal.rec_name)
+        if context.get('batch'):
+            trans_batch = get_translated_item('Batch',
+                'account.batch.line,batch', lang_code)
+            batch = Batch(context['batch'])
+            batch_string = '%s: %s' % (trans_batch, batch.name)
+        if context.get('period'):
+            trans_period = get_translated_item('Period',
+                'account.journal.period,period', lang_code)
+            period = Period(context['period'])
+            period_string = '%s: %s' % (trans_period, period.name)
+        elif context.get('fiscalyear'):
+            trans_fiscalyear = get_translated_item('Fiscal Year',
+                'account.batch.line,fiscalyear', lang_code)
+            fiscalyear = Fiscalyear(context['fiscalyear'])
+            year_string = '%s: %s' % (trans_fiscalyear, fiscalyear.name)
+        return ' | '.join([_f for _f in [
+            batch_string,
+            journal_string,
+            period_string,
+            year_string] if _f])
+
 
 class BatchLine(ModelSQL, ModelView):
     'Account Batch Line'
@@ -359,69 +412,24 @@ class BatchLine(ModelSQL, ModelView):
         cls._check_modify_exclude = {'batch', 'sequence'}
         cls._order[0] = ('id', 'DESC')
 
-    @classmethod
-    def view_header_get(cls, value, view_type='form'):
-        pool = Pool()
-        Batch = pool.get('account.batch')
-        BatchJournal = pool.get('account.batch.journal')
-        Company = pool.get('company.company')
-        Fiscalyear = pool.get('account.fiscalyear')
-        Period = pool.get('account.period')
-        Translation = pool.get('ir.translation')
-
-        name = super(BatchLine, cls).view_header_get(value,
-            view_type=view_type)
-        if not Transaction().context.get('journal'):
-            return name
-
-        lang_code = 'en_US'
-        if Transaction().context.get('company'):
-            company = Company(Transaction().context['company'])
-            if company.party.lang:
-                lang_code = company.party.lang.code
-
-        def get_translated_item(source, model, lang_code):
-            return (Translation.get_source(model, 'field', lang_code, source)
-                or source)
-
-        batch_journal = BatchJournal(Transaction().context['journal'])
-        trans_journal = get_translated_item('Journal',
-            'account.batch.line,journal', lang_code)
-
-        if Transaction().context.get('batch'):
-            trans_batch = get_translated_item('Batch',
-                'account.batch.line,batch', lang_code)
-            batch = Batch(Transaction().context['batch'])
-            name += ' | %s: %s | %s: %s' % (trans_batch,
-                    batch.name, trans_journal, batch_journal.rec_name)
-        else:
-            name += ' | %s: %s' % (trans_journal, batch_journal.rec_name)
-
-        if Transaction().context.get('period'):
-            trans_period = get_translated_item('Period',
-                'account.journal.period,period', lang_code)
-            period = Period(Transaction().context['period'])
-            name += ' | %s: %s' % (trans_period, period.name)
-        elif Transaction().context.get('fiscalyear'):
-            trans_fiscalyear = get_translated_item('Fiscal Year',
-                'account.batch.line,fiscalyear', lang_code)
-            fiscalyear = Fiscalyear(Transaction().context['fiscalyear'])
-            name += ' | %s: %s' % (trans_fiscalyear, fiscalyear.name)
-
-        if Transaction().context.get('header_suffix'):
-            name += ' %s' % (Transaction().context['header_suffix'],)
-        return name
+    def get_rec_name(self, name):
+        return ', '.join([_f for _f in [
+                    self.sequence,
+                    self.party.rec_name if self.party else None,
+                    self.journal.rec_name,
+                    str(self.date) if self.date else None] if _f])
 
     @classmethod
     def fields_view_get(cls, view_id=None, view_type='form'):
         res = super(BatchLine, cls).fields_view_get(view_id=view_id,
                 view_type=view_type)
         res = copy.copy(res)
+        context = Transaction().context
         if res['type'] == 'tree':
-            if Transaction().context.get('journal'):
+            if context.get('journal'):
                 res['arch'] = res['arch'].replace('<field name="journal"',
                         '<field name="journal" tree_invisible="1"')
-            if Transaction().context.get('batch'):
+            if context.get('batch'):
                 res['arch'] = res['arch'].replace('<field name="batch"',
                         '<field name="batch" tree_invisible="1"')
         return res
@@ -439,21 +447,22 @@ class BatchLine(ModelSQL, ModelView):
 
         values = values.copy()
         date = values.get('date', today)
-        company_id = Transaction().context.get('company', False)
+        context = Transaction().context
+        company_id = context.get('company', False)
         if 'fiscalyear' in fields:
             values['fiscalyear'] = Fiscalyear.find(company_id, date=date,
                     exception=True)
 
-        if Transaction().context.get('batch'):
+        if context.get('batch'):
             if 'batch' in fields:
-                values['batch'] = Transaction().context['batch']
+                values['batch'] = context['batch']
 
-        if Transaction().context.get('journal'):
-            journal = BatchJournal(Transaction().context['journal'])
+        if context.get('journal'):
+            journal = BatchJournal(context['journal'])
             account_journal = journal.account_journal
             side = cls._choose_side(_ZERO, account_journal)
             if 'journal' in fields:
-                values['journal'] = Transaction().context.get('journal')
+                values['journal'] = context.get('journal')
 
             if 'account' in fields:
                 values['account'] = journal.account
@@ -482,14 +491,15 @@ class BatchLine(ModelSQL, ModelView):
         BatchJournal = pool.get('account.batch.journal')
 
         res = Date.today()
-        if not Transaction().context.get('journal'):
+        context = Transaction().context
+        if not context.get('journal'):
             return res
 
         account_journal_id = BatchJournal(
-                Transaction().context['journal']).account_journal.id
+                context['journal']).account_journal.id
 
-        if Transaction().context.get('period'):
-            period = Period(Transaction().context['period'])
+        if context.get('period'):
+            period = Period(context['period'])
             args = [
                 ('journal', '=', account_journal_id),
                 ('date', '>', period.start_date),
@@ -500,9 +510,9 @@ class BatchLine(ModelSQL, ModelView):
                 res = moves[0].date
             else:
                 res = period.start_date
-        elif Transaction().context.get('fiscalyear'):
+        elif context.get('fiscalyear'):
             fiscalyear = Fiscalyear(
-                    Transaction().context['fiscalyear'])
+                    context['fiscalyear'])
             args = [
                 ('journal', '=', account_journal_id),
                 ('date', '>', fiscalyear.start_date),
@@ -763,11 +773,8 @@ class BatchLine(ModelSQL, ModelView):
                     ('contra_account', 'in', account_ids),
                     ],
                     ('state', '!=', 'posted'),
-                    ('journal.account_journal.type', '!=', 'situation'),
-                ], limit=1)
-        if lines:
-            return True
-        return False
+                    ('journal.account_journal.type', '!=', 'situation'),])
+        return lines
 
     def set_code(self):
         Sequence = Pool().get('ir.sequence')
